from setuptools import setup

setup(name='rena-distributions',
      version='0.1',
      description='Gaussian & Binomial distributions',
      packages=['rena-distributions'],
      zip_safe=False)
